@@ -3,6 +3,5 @@ from logging import StreamHandler
 
 
 class ConsoleHandler(StreamHandler):
-    def __init__(self, context):
+    def __init__(self, **kwargs):
         super(ConsoleHandler, self).__init__()
-        self.context = context
